Welcome to leap's documentation!
================================

TODO: Insert example here.

:mod:`leap` is based on :mod:`dagrt`.

.. toctree::
    :maxdepth: 2

    reference
    misc
    🚀 Github <https://github.com/inducer/leap>
    💾 Download Releases <https://pypi.org/project/leap>

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
